import { __decorate } from 'tslib';
import { Prop, Model, Component, Vue } from 'vue-property-decorator';
import { CoolSelect, CoolSelectPlugin } from 'vue-cool-select';
import { namespace } from 'vuex-class';

const secureToken = namespace('SecureToken');
/**
 * Class-component
 */
let AssociatePicker = class AssociatePicker extends Vue {
    constructor() {
        super(...arguments);
        this.items = [];
        this.selected = null;
        this.loading = false;
        this.timeoutId = null;
        this.noData = false;
        this.pickerId = Math.random().toString(36).substring(7);
    }
    async onSearch(search) {
        const lettersLimit = 2;
        this.noData = false;
        if (search.length < lettersLimit) {
            this.items = [];
            this.loading = false;
            return;
        }
        this.loading = true;
        clearTimeout(this.timeoutId);
        this.timeoutId = setTimeout(async () => {
            const client = await this.sharepointContext.msGraphClientFactory.getClient();
            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields
            const response = await client
                .api(`/me/people/?$search="${search}"`)
                .version('v1.0')
                .get();
            this.items = response.value.filter((person) => person.userPrincipalName);
            this.loading = false;
            if (!this.items.length) {
                this.noData = true;
            }
        }, 500);
    }
};
__decorate([
    secureToken.Getter
], AssociatePicker.prototype, "sharepointContext", void 0);
__decorate([
    Prop()
], AssociatePicker.prototype, "pickerId", void 0);
__decorate([
    Model('input')
], AssociatePicker.prototype, "value", void 0);
AssociatePicker = __decorate([
    Component({
        components: { CoolSelect },
    })
], AssociatePicker);
var script = AssociatePicker;

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

const isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return (id, style) => addStyle(id, style);
}
let HEAD;
const styles = {};
function addStyle(id, css) {
    const group = isOldIE ? css.media || 'default' : id;
    const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        let code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                style.element.setAttribute('media', css.media);
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            const index = style.ids.size - 1;
            const textNode = document.createTextNode(code);
            const nodes = style.element.childNodes;
            if (nodes[index])
                style.element.removeChild(nodes[index]);
            if (nodes.length)
                style.element.insertBefore(textNode, nodes[index]);
            else
                style.element.appendChild(textNode);
        }
    }
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("cool-select", {
    ref: _vm.pickerId,
    attrs: {
      value: _vm.value,
      id: _vm.pickerId,
      items: _vm.items,
      loading: _vm.loading,
      "item-text": "displayName",
      placeholder: "Enter associate name",
      "disable-filtering-by-search": "",
      "menu-default-position": "bottom",
      "menu-dynamic-position": "false"
    },
    on: {
      input: function($event) {
        return _vm.$emit("input", $event)
      },
      search: function($event) {
        return _vm.onSearch($event)
      }
    },
    scopedSlots: _vm._u([
      {
        key: "no-data",
        fn: function() {
          return [
            _vm._v(
              "\n        " +
                _vm._s(
                  _vm.noData
                    ? "No associates found."
                    : "Enter at least 2 letters to search."
                ) +
                "\n    "
            )
          ]
        },
        proxy: true
      },
      {
        key: "item",
        fn: function(ref) {
          var item = ref.item;
          return [
            _c("div", { staticClass: "item" }, [
              _c("img", {
                staticClass: "logo",
                attrs: {
                  src:
                    "https://mccowngordon.sharepoint.com/_layouts/15/userphoto.aspx?size=S&accountname=" +
                    item.userPrincipalName
                }
              }),
              _vm._v(" "),
              _c("div", [
                _c("span", { staticClass: "item-name" }, [
                  _vm._v(_vm._s(item.displayName))
                ]),
                _vm._v(" "),
                _c("br"),
                _vm._v(" "),
                _c("span", { staticClass: "item-domain" }, [
                  _vm._v(_vm._s(item.jobTitle))
                ])
              ])
            ])
          ]
        }
      }
    ])
  })
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-e542178e_0", { source: ".IZ-select * {\n  box-sizing: border-box;\n}\n.IZ-select__input-wrap {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n.IZ-select__input,\n.IZ-select__input input {\n  height: 100%;\n}\n.fade-leave-active {\n  position: absolute;\n}\n.fade-enter-active,\n.fade-leave,\n.fade-leave-to {\n  transition: opacity 0.2s;\n}\n.fade-enter,\n.fade-leave-to {\n  opacity: 0;\n}\n.IZ-select {\n  position: relative;\n  outline: none;\n}\n.IZ-select .IZ-select__input {\n  font-weight: 400;\n  font-size: 1rem;\n  line-height: 1.5;\n}\n.IZ-select .IZ-select__input input {\n  height: calc(1.5em + 0.75rem);\n  padding: 0.375rem 0.75rem;\n}\n.IZ-select--sm .IZ-select__input {\n  border-radius: 0.2rem;\n}\n.IZ-select--sm .IZ-select__input input {\n  height: calc(1.5em + 0.5rem);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.875rem;\n  line-height: 1.5;\n}\n.IZ-select--lg .IZ-select__input {\n  border-radius: 0.3rem;\n}\n.IZ-select--lg .IZ-select__input input {\n  height: calc(1.5em + 1rem);\n  padding: 0.5rem 1rem;\n  font-size: 1.25rem;\n  line-height: 1.5;\n}\n.IZ-select__input {\n  align-items: center;\n  display: flex;\n  flex: 1 1 auto;\n  flex-wrap: wrap;\n  width: 100%;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n.IZ-select__input.IZ-select__input--selection-slot {\n  padding-left: 0.75rem;\n}\n.IZ-select__input.IZ-select__input--selection-slot input {\n  padding-left: 10px;\n}\n.IZ-select__input.IZ-select__input--has-error {\n  border: 1px solid #dc3545 !important;\n  caret-color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--has-error input {\n  color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--successful {\n  border: 1px solid #28a745 !important;\n  caret-color: #28c346 !important;\n}\n.IZ-select__input.IZ-select__input--focused {\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--disabled {\n  pointer-events: none;\n  background-color: #e9ecef;\n  opacity: 1;\n}\n.IZ-select__input.IZ-select__input--disabled input {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::placeholder {\n  color: #6c737a !important;\n}\n.IZ-select__input input {\n  font-size: 1rem;\n  background-size: 25px 25px;\n  background-position: right 10px center;\n  background-repeat: no-repeat;\n  color: #495057 !important;\n  background-color: transparent;\n  border-style: none;\n  pointer-events: auto;\n  flex: 1 1;\n  margin-top: 0;\n  min-width: 0;\n  position: relative;\n  line-height: 20px;\n  max-width: 100%;\n  width: 100%;\n}\n.IZ-select__input input:focus {\n  outline: none;\n}\n.IZ-select__input input:disabled {\n  pointer-events: none;\n}\n.IZ-select__menu {\n  opacity: 0;\n  transition: opacity 0.1s;\n  position: absolute;\n  z-index: 8;\n  transform-origin: left top 0;\n  background-color: #fff;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\n}\n.IZ-select__menu--at-top {\n  border-bottom: 0;\n  border-bottom-left-radius: 0;\n  border-bottom-right-radius: 0;\n}\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\n  border-bottom: 1px;\n  border-bottom-left-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n.IZ-select__menu--at-bottom {\n  border-top: 0;\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\n  border-top: 1px;\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n.IZ-select__menu .IZ-select__menu-items {\n  overflow-y: auto;\n  overflow-x: hidden;\n}\n.IZ-select__menu .IZ-select__no-data {\n  margin: 0 10px;\n}\n.IZ-select__item {\n  cursor: pointer;\n  padding: 10px 14px;\n  transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\n}\n.IZ-select__item:hover {\n  background-color: #f2f2f2;\n}\n.IZ-select__item.IZ-select__item--selected {\n  color: #1976d2 !important;\n}\n.IZ-select__error {\n  margin-top: 0.55rem;\n  font-size: 85%;\n  color: #dc3545;\n}\n.item {\n  display: flex;\n  align-items: center;\n}\n.item-domain {\n  color: grey;\n}\n.logo {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */", map: {"version":3,"sources":["C:\\Users\\astanley\\local web\\npm packages\\vue-ui-components\\src\\components\\AssociatePicker.vue","AssociatePicker.vue"],"names":[],"mappings":"AAuGA;EACA,sBAAA;ACtGA;ADwGA;EACA,aAAA;EACA,mBAAA;EACA,YAAA;ACrGA;ADuGA;;EAEA,YAAA;ACpGA;ADsGA;EACA,kBAAA;ACnGA;ADqGA;;;EAGA,wBAAA;AClGA;ADoGA;;EAEA,UAAA;ACjGA;ADmGA;EACA,kBAAA;EACA,aAAA;AChGA;ADkGA;EACA,gBAAA;EACA,eAAA;EACA,gBAAA;AC/FA;ADiGA;EACA,6BAAA;EACA,yBAAA;AC9FA;ADgGA;EACA,qBAAA;AC7FA;AD+FA;EACA,4BAAA;EACA,uBAAA;EACA,mBAAA;EACA,gBAAA;AC5FA;AD8FA;EACA,qBAAA;AC3FA;AD6FA;EACA,0BAAA;EACA,oBAAA;EACA,kBAAA;EACA,gBAAA;AC1FA;AD4FA;EACA,mBAAA;EACA,aAAA;EACA,cAAA;EACA,eAAA;EACA,WAAA;EACA,cAAA;EACA,sBAAA;EACA,4BAAA;EACA,yBAAA;EACA,sBAAA;EACA,4GAAA;ACzFA;AD2FA;EACA,qBAAA;ACxFA;AD0FA;EACA,kBAAA;ACvFA;ADyFA;EACA,oCAAA;EACA,+BAAA;ACtFA;ADwFA;EACA,yBAAA;ACrFA;ADuFA;EACA,oCAAA;EACA,+BAAA;ACpFA;ADsFA;EACA,qBAAA;EACA,UAAA;EACA,iDAAA;ACnFA;ADqFA;EACA,2DAAA;AClFA;ADoFA;EACA,2DAAA;ACjFA;ADmFA;EACA,oBAAA;EACA,yBAAA;EACA,UAAA;AChFA;ADkFA;EACA,yBAAA;AC/EA;ADiFA;EACA,yBAAA;AC9EA;ADgFA;EACA,yBAAA;AC7EA;AD+EA;EACA,yBAAA;AC5EA;AD8EA;EACA,yBAAA;AC3EA;AD6EA;EACA,yBAAA;AC1EA;AD4EA;EACA,eAAA;EACA,0BAAA;EACA,sCAAA;EACA,4BAAA;EACA,yBAAA;EACA,6BAAA;EACA,kBAAA;EACA,oBAAA;EACA,SAAA;EACA,aAAA;EACA,YAAA;EACA,kBAAA;EACA,iBAAA;EACA,eAAA;EACA,WAAA;ACzEA;AD2EA;EACA,aAAA;ACxEA;AD0EA;EACA,oBAAA;ACvEA;ADyEA;EACA,UAAA;EACA,wBAAA;EACA,kBAAA;EACA,UAAA;EACA,4BAAA;EACA,sBAAA;EACA,yBAAA;EACA,sBAAA;EACA,+CAAA;ACtEA;ADwEA;EACA,gBAAA;EACA,4BAAA;EACA,6BAAA;ACrEA;ADuEA;EACA,kBAAA;EACA,kCAAA;EACA,mCAAA;ACpEA;ADsEA;EACA,aAAA;EACA,yBAAA;EACA,0BAAA;ACnEA;ADqEA;EACA,eAAA;EACA,+BAAA;EACA,gCAAA;AClEA;ADoEA;EACA,gBAAA;EACA,kBAAA;ACjEA;ADmEA;EACA,cAAA;AChEA;ADkEA;EACA,eAAA;EACA,kBAAA;EACA,gDAAA;AC/DA;ADiEA;EACA,yBAAA;AC9DA;ADgEA;EACA,yBAAA;AC7DA;AD+DA;EACA,mBAAA;EACA,cAAA;EACA,cAAA;AC5DA;AD8DA;EACA,aAAA;EACA,mBAAA;AC3DA;ADiEA;EACA,WAAA;AC9DA;ADiEA;EACA,eAAA;EACA,kBAAA;EACA,yBAAA;AC9DA;ADiEA;EACA,WAAA;EACA,kBAAA;AC9DA;;AAEA,8CAA8C","file":"AssociatePicker.vue","sourcesContent":["<template>\n    <cool-select\n        :value=\"value\"\n        @input=\"$emit('input', $event)\"\n        :id=\"pickerId\"\n        :ref=\"pickerId\"\n        :items=\"items\"\n        :loading=\"loading\"\n        item-text=\"displayName\"\n        placeholder=\"Enter associate name\"\n        disable-filtering-by-search\n        menu-default-position=\"bottom\"\n        menu-dynamic-position=\"false\"\n        @search=\"onSearch($event)\"\n    >\n        <template #no-data>\n            {{ noData ? 'No associates found.' : 'Enter at least 2 letters to search.' }}\n        </template>\n        <template #item=\"{ item }\">\n            <div class=\"item\">\n                <img\n                    :src=\"\n                        'https://mccowngordon.sharepoint.com/_layouts/15/userphoto.aspx?size=S&accountname=' +\n                            item.userPrincipalName\n                    \"\n                    class=\"logo\"\n                />\n\n                <div>\n                    <span class=\"item-name\">{{ item.displayName }}</span>\n                    <br />\n                    <span class=\"item-domain\">{{ item.jobTitle }}</span>\n                </div>\n            </div>\n        </template>\n    </cool-select>\n</template>\n\n<script lang=\"ts\">\nimport { Vue, Component, Prop, Model } from 'vue-property-decorator';\n\nimport { CoolSelect } from 'vue-cool-select';\nimport { MSGraphClient } from '@microsoft/sp-http';\n\nimport { namespace } from 'vuex-class';\nconst secureToken = namespace('SecureToken');\n\n/**\n * Class-component\n */\n\n@Component({\n    components: { CoolSelect },\n})\nexport default class AssociatePicker extends Vue {\n    @secureToken.Getter\n    public sharepointContext;\n\n    items = [];\n    selected = null;\n    loading = false;\n    timeoutId: any = null;\n    noData = false;\n\n    @Prop()\n    public pickerId: string = Math.random().toString(36).substring(7);\n\n    @Model('input')\n    public value;\n\n\n\n    public async onSearch(search) {\n        const lettersLimit = 2;\n\n        this.noData = false;\n        if (search.length < lettersLimit) {\n            this.items = [];\n            this.loading = false;\n            return;\n        }\n        this.loading = true;\n\n        clearTimeout(this.timeoutId);\n        this.timeoutId = setTimeout(async () => {\n            const client: MSGraphClient = await this.sharepointContext.msGraphClientFactory.getClient();\n            // https://stackoverflow.com/a/58647582/823927 - We just have to get back a ton of extra fields\n            const response = await client\n                .api(`/me/people/?$search=\"${search}\"`)\n                .version('v1.0')\n                .get();\n            this.items = response.value.filter((person) => person.userPrincipalName);\n            this.loading = false;\n            if (!this.items.length) {\n                this.noData = true;\n            }\n        }, 500);\n    }\n}\n</script>\n\n<style lang=\"scss\">\n// importing the bootstrap theme from cool select here\n.IZ-select * {\n    box-sizing: border-box;\n}\n.IZ-select__input-wrap {\n    display: flex;\n    align-items: center;\n    height: 100%;\n}\n.IZ-select__input,\n.IZ-select__input input {\n    height: 100%;\n}\n.fade-leave-active {\n    position: absolute;\n}\n.fade-enter-active,\n.fade-leave,\n.fade-leave-to {\n    transition: opacity 0.2s;\n}\n.fade-enter,\n.fade-leave-to {\n    opacity: 0;\n}\n.IZ-select {\n    position: relative;\n    outline: none;\n}\n.IZ-select .IZ-select__input {\n    font-weight: 400;\n    font-size: 1rem;\n    line-height: 1.5;\n}\n.IZ-select .IZ-select__input input {\n    height: calc(1.5em + 0.75rem);\n    padding: 0.375rem 0.75rem;\n}\n.IZ-select--sm .IZ-select__input {\n    border-radius: 0.2rem;\n}\n.IZ-select--sm .IZ-select__input input {\n    height: calc(1.5em + 0.5rem);\n    padding: 0.25rem 0.5rem;\n    font-size: 0.875rem;\n    line-height: 1.5;\n}\n.IZ-select--lg .IZ-select__input {\n    border-radius: 0.3rem;\n}\n.IZ-select--lg .IZ-select__input input {\n    height: calc(1.5em + 1rem);\n    padding: 0.5rem 1rem;\n    font-size: 1.25rem;\n    line-height: 1.5;\n}\n.IZ-select__input {\n    align-items: center;\n    display: flex;\n    flex: 1 1 auto;\n    flex-wrap: wrap;\n    width: 100%;\n    color: #495057;\n    background-color: #fff;\n    background-clip: padding-box;\n    border: 1px solid #ced4da;\n    border-radius: 0.25rem;\n    transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n.IZ-select__input.IZ-select__input--selection-slot {\n    padding-left: 0.75rem;\n}\n.IZ-select__input.IZ-select__input--selection-slot input {\n    padding-left: 10px;\n}\n.IZ-select__input.IZ-select__input--has-error {\n    border: 1px solid #dc3545 !important;\n    caret-color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--has-error input {\n    color: #ff5252 !important;\n}\n.IZ-select__input.IZ-select__input--successful {\n    border: 1px solid #28a745 !important;\n    caret-color: #28c346 !important;\n}\n.IZ-select__input.IZ-select__input--focused {\n    border-color: #80bdff;\n    outline: 0;\n    box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\n    box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\n    box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\n}\n.IZ-select__input.IZ-select__input--disabled {\n    pointer-events: none;\n    background-color: #e9ecef;\n    opacity: 1;\n}\n.IZ-select__input.IZ-select__input--disabled input {\n    color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\n    color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\n    color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\n    color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\n    color: #6c737a !important;\n}\n.IZ-select__input.IZ-select__input--disabled::placeholder {\n    color: #6c737a !important;\n}\n.IZ-select__input input {\n    font-size: 1rem;\n    background-size: 25px 25px;\n    background-position: right 10px center;\n    background-repeat: no-repeat;\n    color: #495057 !important;\n    background-color: transparent;\n    border-style: none;\n    pointer-events: auto;\n    flex: 1 1;\n    margin-top: 0;\n    min-width: 0;\n    position: relative;\n    line-height: 20px;\n    max-width: 100%;\n    width: 100%;\n}\n.IZ-select__input input:focus {\n    outline: none;\n}\n.IZ-select__input input:disabled {\n    pointer-events: none;\n}\n.IZ-select__menu {\n    opacity: 0;\n    transition: opacity 0.1s;\n    position: absolute;\n    z-index: 8;\n    transform-origin: left top 0;\n    background-color: #fff;\n    border: 1px solid #ced4da;\n    border-radius: 0.25rem;\n    box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\n}\n.IZ-select__menu--at-top {\n    border-bottom: 0;\n    border-bottom-left-radius: 0;\n    border-bottom-right-radius: 0;\n}\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\n    border-bottom: 1px;\n    border-bottom-left-radius: 0.25rem;\n    border-bottom-right-radius: 0.25rem;\n}\n.IZ-select__menu--at-bottom {\n    border-top: 0;\n    border-top-left-radius: 0;\n    border-top-right-radius: 0;\n}\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\n    border-top: 1px;\n    border-top-left-radius: 0.25rem;\n    border-top-right-radius: 0.25rem;\n}\n.IZ-select__menu .IZ-select__menu-items {\n    overflow-y: auto;\n    overflow-x: hidden;\n}\n.IZ-select__menu .IZ-select__no-data {\n    margin: 0 10px;\n}\n.IZ-select__item {\n    cursor: pointer;\n    padding: 10px 14px;\n    transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\n}\n.IZ-select__item:hover {\n    background-color: #f2f2f2;\n}\n.IZ-select__item.IZ-select__item--selected {\n    color: #1976d2 !important;\n}\n.IZ-select__error {\n    margin-top: 0.55rem;\n    font-size: 85%;\n    color: #dc3545;\n}\n.item {\n    display: flex;\n    align-items: center;\n}\n\n// .item-name {\n//     font-size: 25px;\n// }\n.item-domain {\n    color: grey;\n}\n\n.logo {\n    max-width: 60px;\n    margin-right: 10px;\n    border: 1px solid #eaecf0;\n}\n\n.loading-indicator {\n    width: 20px;\n    margin-right: 10px;\n}\n</style>\n",".IZ-select * {\n  box-sizing: border-box;\n}\n\n.IZ-select__input-wrap {\n  display: flex;\n  align-items: center;\n  height: 100%;\n}\n\n.IZ-select__input,\n.IZ-select__input input {\n  height: 100%;\n}\n\n.fade-leave-active {\n  position: absolute;\n}\n\n.fade-enter-active,\n.fade-leave,\n.fade-leave-to {\n  transition: opacity 0.2s;\n}\n\n.fade-enter,\n.fade-leave-to {\n  opacity: 0;\n}\n\n.IZ-select {\n  position: relative;\n  outline: none;\n}\n\n.IZ-select .IZ-select__input {\n  font-weight: 400;\n  font-size: 1rem;\n  line-height: 1.5;\n}\n\n.IZ-select .IZ-select__input input {\n  height: calc(1.5em + 0.75rem);\n  padding: 0.375rem 0.75rem;\n}\n\n.IZ-select--sm .IZ-select__input {\n  border-radius: 0.2rem;\n}\n\n.IZ-select--sm .IZ-select__input input {\n  height: calc(1.5em + 0.5rem);\n  padding: 0.25rem 0.5rem;\n  font-size: 0.875rem;\n  line-height: 1.5;\n}\n\n.IZ-select--lg .IZ-select__input {\n  border-radius: 0.3rem;\n}\n\n.IZ-select--lg .IZ-select__input input {\n  height: calc(1.5em + 1rem);\n  padding: 0.5rem 1rem;\n  font-size: 1.25rem;\n  line-height: 1.5;\n}\n\n.IZ-select__input {\n  align-items: center;\n  display: flex;\n  flex: 1 1 auto;\n  flex-wrap: wrap;\n  width: 100%;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n\n.IZ-select__input.IZ-select__input--selection-slot {\n  padding-left: 0.75rem;\n}\n\n.IZ-select__input.IZ-select__input--selection-slot input {\n  padding-left: 10px;\n}\n\n.IZ-select__input.IZ-select__input--has-error {\n  border: 1px solid #dc3545 !important;\n  caret-color: #ff5252 !important;\n}\n\n.IZ-select__input.IZ-select__input--has-error input {\n  color: #ff5252 !important;\n}\n\n.IZ-select__input.IZ-select__input--successful {\n  border: 1px solid #28a745 !important;\n  caret-color: #28c346 !important;\n}\n\n.IZ-select__input.IZ-select__input--focused {\n  border-color: #80bdff;\n  outline: 0;\n  box-shadow: 0 0 0 0.2rem rgba(128, 189, 255, 0.5);\n}\n\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--has-error {\n  box-shadow: 0 0 0 0.2rem rgba(220, 53, 69, 0.25) !important;\n}\n\n.IZ-select__input.IZ-select__input--focused.IZ-select__input--successful {\n  box-shadow: 0 0 0 0.2rem rgba(40, 167, 69, 0.25) !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled {\n  pointer-events: none;\n  background-color: #e9ecef;\n  opacity: 1;\n}\n\n.IZ-select__input.IZ-select__input--disabled input {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-webkit-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-moz-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled:-ms-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::-ms-input-placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input.IZ-select__input--disabled::placeholder {\n  color: #6c737a !important;\n}\n\n.IZ-select__input input {\n  font-size: 1rem;\n  background-size: 25px 25px;\n  background-position: right 10px center;\n  background-repeat: no-repeat;\n  color: #495057 !important;\n  background-color: transparent;\n  border-style: none;\n  pointer-events: auto;\n  flex: 1 1;\n  margin-top: 0;\n  min-width: 0;\n  position: relative;\n  line-height: 20px;\n  max-width: 100%;\n  width: 100%;\n}\n\n.IZ-select__input input:focus {\n  outline: none;\n}\n\n.IZ-select__input input:disabled {\n  pointer-events: none;\n}\n\n.IZ-select__menu {\n  opacity: 0;\n  transition: opacity 0.1s;\n  position: absolute;\n  z-index: 8;\n  transform-origin: left top 0;\n  background-color: #fff;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  box-shadow: 0 2px 11px -2px rgba(0, 0, 0, 0.19);\n}\n\n.IZ-select__menu--at-top {\n  border-bottom: 0;\n  border-bottom-left-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.IZ-select__menu--at-top.IZ-select__menu--disable-search {\n  border-bottom: 1px;\n  border-bottom-left-radius: 0.25rem;\n  border-bottom-right-radius: 0.25rem;\n}\n\n.IZ-select__menu--at-bottom {\n  border-top: 0;\n  border-top-left-radius: 0;\n  border-top-right-radius: 0;\n}\n\n.IZ-select__menu--at-bottom.IZ-select__menu--disable-search {\n  border-top: 1px;\n  border-top-left-radius: 0.25rem;\n  border-top-right-radius: 0.25rem;\n}\n\n.IZ-select__menu .IZ-select__menu-items {\n  overflow-y: auto;\n  overflow-x: hidden;\n}\n\n.IZ-select__menu .IZ-select__no-data {\n  margin: 0 10px;\n}\n\n.IZ-select__item {\n  cursor: pointer;\n  padding: 10px 14px;\n  transition: 0.3s cubic-bezier(0.25, 0.8, 0.5, 1);\n}\n\n.IZ-select__item:hover {\n  background-color: #f2f2f2;\n}\n\n.IZ-select__item.IZ-select__item--selected {\n  color: #1976d2 !important;\n}\n\n.IZ-select__error {\n  margin-top: 0.55rem;\n  font-size: 85%;\n  color: #dc3545;\n}\n\n.item {\n  display: flex;\n  align-items: center;\n}\n\n.item-domain {\n  color: grey;\n}\n\n.logo {\n  max-width: 60px;\n  margin-right: 10px;\n  border: 1px solid #eaecf0;\n}\n\n.loading-indicator {\n  width: 20px;\n  margin-right: 10px;\n}\n\n/*# sourceMappingURL=AssociatePicker.vue.map */"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

// import Vuex from 'vuex';
// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) {
        return;
    }
    install.installed = true;
    // check to see if vue secure plugin is installed and throw an error if not
    // we need sharepointContext to work
    Vue.use(CoolSelectPlugin);
    Vue.component('AssociatePicker', __vue_component__);
}
// Create module definition for Vue.use()
const plugin = {
    install,
};
// Auto-install when vue is found (eg. in browser via <script> tag)
let GlobalVue;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
}
else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}
// export { AssociatePicker };

export default plugin;
//# sourceMappingURL=vueUIComponents.esm.js.map
